@@ -28,6 +28,7 @@
 #include <libgda/libgda.h>
 #include "qof.h"
 #include "qof-gda.h"
+#include "qofsql-p.h"
 
 #define _(String) dgettext (GETTEXT_PACKAGE, String)
 #define ACCESS_METHOD  "gda"
@@ -37,6 +38,9 @@
 #define GDA_PASSWORD   "gda-password"
 #define GDA_DATASOURCE "qof-gda-source"
 
+/** enable for debug */
+#define ONLY_DEBUG 1
+
 /** @file  qof-gda.c
 	@brief Public interface of qof-backend-gda
 	@author Copyright 2006-2008 Neil Williams <linux@codehelp.co.uk>
@@ -50,19 +54,16 @@ typedef struct
 	GdaClient * client_pool;
 	GdaConnection * connection;
 	GdaCommand * command;
-	GdaDataModel * dm;
 	GValue * gda_value;
 	/* GdaTransaction is now just a string label */
 	gchar * undo_trans, * commit_trans;
 	GError * gda_err;
-	const GdaColumn *gda_param;
 	GList * entities;
 	gint dbversion;
 	gint create_handler;
 	gint delete_handler;
 	const gchar *fullpath;
 	const gchar * table_name;   /* revised each iteration. */
-	GSList * field_list;
 	/* QofBackendOption settings: */
 	gchar * data_source_name;
 	gchar * provider_name;
@@ -70,12 +71,18 @@ typedef struct
 	gchar * source_description;
 	gchar * username;
 	gchar * password;
+	gchar * gdahome;
 	/* end QofBackendOption */
 	gchar *err;
 	gchar *sql_str;
+	/** list of other dirty entities */
+	GList *dirty_list;
+	/** whether to use UPDATE or INSERT */
+	gboolean exists;
 	gboolean error;
 	QofIdType e_type;
 	QofBook * book;
+	QofErrorId err_delete, err_insert, err_update, err_create;
 } QGdaBackend;
 
 static gboolean
@@ -90,136 +97,90 @@ qgda_determine_file_type (const gchar * path)
 static void
 qgda_modify (QofBackend *be, QofInstance *inst)
 {
+	QGdaBackend *qgda_be;
 
-}
-
-static GdaColumn *
-qoftype_to_gdafield (QofIdTypeConst qoftype)
-{
-	GdaColumn *p;
-
-	p = gda_column_new();
-	gda_column_set_allow_null (p, TRUE);
-	gda_column_set_g_type (p, G_TYPE_NONE);
-	if (0 == safe_strcasecmp (qoftype, QOF_TYPE_STRING))
-		gda_column_set_g_type (p, G_TYPE_STRING);
-	if (0 == safe_strcasecmp (qoftype, QOF_TYPE_GUID))
-	{
-		gda_column_set_g_type (p, G_TYPE_STRING);
-		gda_column_set_allow_null (p, FALSE);
-		gda_column_set_primary_key (p, TRUE);
-	}
-	if (0 == safe_strcasecmp (qoftype, QOF_TYPE_CHAR))
-		gda_column_set_g_type (p, G_TYPE_STRING);
-	if ((0 == safe_strcasecmp (qoftype, QOF_TYPE_DOUBLE)) ||
-		(0 == safe_strcasecmp (qoftype, QOF_TYPE_NUMERIC)) ||
-		(0 == safe_strcasecmp (qoftype, QOF_TYPE_DEBCRED)))
-		gda_column_set_g_type (p, G_TYPE_DOUBLE);
-	if (0 == safe_strcasecmp (qoftype, QOF_TYPE_TIME))
-		gda_column_set_g_type (p, G_TYPE_DATE);
-	if (0 == safe_strcasecmp (qoftype, QOF_TYPE_BOOLEAN))
-		gda_column_set_g_type (p, G_TYPE_BOOLEAN);
-	if (0 == safe_strcasecmp (qoftype, QOF_TYPE_INT32))
-		gda_column_set_g_type (p, G_TYPE_INT);
-	if (0 == safe_strcasecmp (qoftype, QOF_TYPE_INT64))
-		gda_column_set_g_type (p, G_TYPE_INT64);
-/*	if (0 == safe_strcasecmp (qoftype, QOF_TYPE_KVP))
-		gda_column_set_g_type (p, G_TYPE_); ??
-*/
-	if (gda_column_get_g_type (p) == G_TYPE_NONE)
-	{
-		g_free (p);
-		return NULL;
-	}
-	return p;
-}
-
-static void
-convert_params (QofParam * param, gpointer user_data)
-{
-	GdaColumn * p;
-	QGdaBackend * qgda_be;
-
-	qgda_be = (QGdaBackend*)user_data;
-	if (!param)
+	qgda_be = (QGdaBackend *) be;
+	if (!inst)
 		return;
-	if (0 == safe_strcasecmp (param->param_type, QOF_ID_BOOK))
+	if (!inst->param)
 		return;
-	p = qoftype_to_gdafield (param->param_type);
-	if (!p)
+//	if (loading)
+//		return;
+	if (!inst->param->param_setfcn)
+		return;
+	qgda_be->gda_err = NULL;
+	ENTER (" modified %s param:%s", ((QofEntity *) inst)->e_type, inst->param->param_name);
+	qgda_be->sql_str = qof_sql_entity_update ((QofEntity*)inst);
+	if (!qgda_be->sql_str)
 	{
-		DEBUG (" unsupported QofParam: %s %s",
-			param->param_name, param->param_type);
+		LEAVE (" null string");
 		return;
 	}
-	gda_column_set_name (p, param->param_name);
-	gda_column_set_table (p, qgda_be->table_name);
-	qgda_be->field_list = g_slist_append (qgda_be->field_list, p);
-	PINFO (" name=%s table=%s type=%s", param->param_name,
-		qgda_be->table_name, param->param_type);
-}
-
-static void
-build_table (gpointer value, gpointer user_data)
-{
-	QGdaBackend * qgda_be;
-	GdaParameterList * plist;
-	GError * qgda_err;
-	gint c;
-
-	qgda_err = NULL;
-	qgda_be = (QGdaBackend*)user_data;
-	if (!gda_connection_is_opened (qgda_be->connection))
+	DEBUG (" sql_str=%s", qgda_be->sql_str);
+	qgda_be->command = gda_command_new (qgda_be->sql_str, GDA_COMMAND_TYPE_SQL, 
+		GDA_COMMAND_OPTION_STOP_ON_ERRORS);
+	gda_connection_execute_non_select_command (qgda_be->connection, 
+		qgda_be->command, NULL, &qgda_be->gda_err);
+	if (qgda_be->gda_err)
 	{
-		/* this probably needs to be a user error/ */
-		PERR (" no connection to gda available");
+		qof_error_set_be (be, qgda_be->err_update);
+		qgda_be->error = TRUE;
+		PERR (" error on modify:%s", qgda_be->err);
+		LEAVE (" ");
+		g_error_free (qgda_be->gda_err);
+		qgda_be->gda_err = NULL;
 		return;
 	}
-	PINFO (" length=%d", g_slist_length(qgda_be->field_list));
-	c = g_slist_length(qgda_be->field_list);
-	if (c > 0)
-	{
-		gchar * text;
-
-		/* need a plain text SQL statement for the table. 
-		(meaning that this will end up looking a lot like
-		QSQLiteBackend).
-		*/
-		text = g_strdup ("create table ... ");
-		plist = NULL;
-		qgda_be->command = gda_command_new (text, GDA_COMMAND_TYPE_SQL, 
-			GDA_COMMAND_OPTION_STOP_ON_ERRORS);
-		gda_connection_execute_non_select_command (qgda_be->connection, 
-			qgda_be->command, plist, &qgda_err);
-		/* plist contains a GdaParameterList of results - probably ignore. */
-		if (qgda_err)
-		{
-			/* handle the error here */
-			g_clear_error (&qgda_err);
-		}
-		gda_command_free (qgda_be->command);
-	}
+	inst->dirty = FALSE;
+	g_free (qgda_be->sql_str);
+	qgda_be->error = FALSE;
+	LEAVE (" ");
 }
 
 static void
 create_tables (QofObject * obj, gpointer user_data)
 {
 	QGdaBackend * qgda_be;
+	QofBackend * be;
+//	GdaParameterList * plist;
+	gchar * str;
 
 	qgda_be = (QGdaBackend*)user_data;
-	if (qgda_be->field_list)
-		g_slist_free (qgda_be->field_list);
-	qgda_be->field_list = NULL;
-	qgda_be->table_name = obj->e_type;
-	qof_class_param_foreach (obj->e_type, convert_params,
-		qgda_be);
-	g_slist_foreach (qgda_be->field_list, build_table, qgda_be);
+	be = (QofBackend*)qgda_be;
+	if (!gda_connection_is_opened (qgda_be->connection))
+	{
+		qof_error_set_be (be, qof_error_register
+			(_("GDA: No connection available."), FALSE));
+		qgda_be->error = TRUE;
+		PERR (" no connection to gda available");
+		return;
+	}
+	qgda_be->gda_err = NULL;
+	str = qof_sql_object_create_table (obj);
+	qgda_be->command = gda_command_new (str, GDA_COMMAND_TYPE_SQL, 
+		GDA_COMMAND_OPTION_STOP_ON_ERRORS);
+	gda_connection_execute_non_select_command (qgda_be->connection, 
+		qgda_be->command, NULL, &qgda_be->gda_err);
+	if (qgda_be->gda_err)
+	{
+		gchar * msg;
+
+		/* Translators: the string is the error message from GDA */
+		msg = g_strdup_printf (_("GDA: Error: %s"), qgda_be->gda_err->message);
+		qof_error_set_be (be, qof_error_register (msg, FALSE));
+		qgda_be->error = TRUE;
+		g_error_free (qgda_be->gda_err);
+		g_free (msg);
+	}
+	qof_sql_entity_set_kvp_exists (TRUE);
+//	g_free (plist);
+	gda_command_free (qgda_be->command);
 }
 
 static gboolean
 create_data_source (QGdaBackend * qgda_be)
 {
-	gchar * cnc_string;
+	gchar * cnc_string, * msg;
 	QofBackend * be;
 	GdaProviderInfo * prov;
 
@@ -232,11 +193,11 @@ create_data_source (QGdaBackend * qgda_be)
 		LEAVE (" empty data source name");
 		return FALSE;
 	}
+	qgda_be->gda_err = NULL;
 	prov = gda_config_get_provider_by_name (qgda_be->provider_name);
 	if (!prov)
 	{
-		gchar * msg;
-
+		/* Translators: The string is the GDA provider name. */
 		msg = g_strdup_printf (_("GDA Provider '%s' could not be found"),
 			qgda_be->provider_name);
 		qof_error_set_be (be, qof_error_register(msg, FALSE));
@@ -244,14 +205,52 @@ create_data_source (QGdaBackend * qgda_be)
 		LEAVE (" provider '%s' not found", qgda_be->provider_name);
 		return FALSE;
 	}
-/*	cnc_string = g_strconcat ("DATABASE=", qgda_be->database_name,
-		NULL);*/
-	cnc_string = g_strdup ("URI=/home/neil/gda-test.db");
+	cnc_string = g_strconcat ("DB_DIR=", qgda_be->gdahome, ";DB_NAME=", 
+		qgda_be->database_name, NULL);
 	/* creates db within source if db does not exist */
-	gda_config_save_data_source (qgda_be->data_source_name,
-		qgda_be->provider_name, cnc_string,
-		qgda_be->source_description, qgda_be->username,
-		qgda_be->password, TRUE);
+	{
+		GdaServerOperation * prepare;
+		gboolean modify_global_config, save_data_source, test;
+		prepare = gda_client_prepare_create_database (qgda_be->client_pool, 
+			qgda_be->data_source_name, qgda_be->provider_name);
+		test = gda_client_perform_create_database (qgda_be->client_pool, prepare, NULL);
+		if (test)
+			PINFO ("performed creation of new database ok");
+		else
+			PERR ("creation of new database failed");
+		modify_global_config = gda_config_can_modify_global_config ();
+		/* only the root user can modify global config in GDA - find out */
+		gda_config_has_section ("/apps/libgda/Datasources/QOF_DEBUG");
+		modify_global_config = gda_config_can_modify_global_config ();
+		save_data_source = gda_config_save_data_source (qgda_be->data_source_name,
+			qgda_be->provider_name, cnc_string,
+			qgda_be->source_description, qgda_be->username,
+			qgda_be->password, modify_global_config);
+		g_return_val_if_fail (save_data_source, FALSE);
+	}
+	qgda_be->connection = gda_client_open_connection
+		(qgda_be->client_pool, qgda_be->data_source_name,
+		NULL, NULL, GDA_CONNECTION_OPTIONS_NONE, &qgda_be->gda_err);
+	if (!qgda_be->connection)
+	{
+		gchar * msg;
+		/* Translators: First string is the data source name,
+		second string is the message from GDA. */
+		msg = g_strdup_printf 
+			(_("GDA: Failed to connect to the data source '%s'. "
+			"The GDA error was '%s'."),	qgda_be->data_source_name, 
+			qgda_be->gda_err->message);
+		qof_error_set_be (be, qof_error_register (msg, FALSE));
+		g_free (msg);
+		qgda_be->error = TRUE;
+#ifdef ONLY_DEBUG
+		PERR ("connect request failed, removing %s", qgda_be->data_source_name);
+		g_message ("connect request failed, removing %s", qgda_be->data_source_name);
+		gda_config_remove_data_source (qgda_be->data_source_name);
+#endif
+		g_error_free (qgda_be->gda_err);
+		return FALSE;
+	}
 	/* create tables per QofObject */
 	qof_object_foreach_type (create_tables, qgda_be);
 	/* gda_connection_create_table (don't log password) */
@@ -268,14 +267,14 @@ qgda_session_begin(QofBackend *be, QofSession *session, const
 				   gboolean create_if_nonexistent)
 {
 	QGdaBackend *qgda_be;
-	GError * qgda_err;
-//	GList * connection_errors, *node;
+	GdaDataSourceInfo * source;
+	gboolean created;
 
-	qgda_err = NULL;
 	/* cannot use ignore_lock */
 	PINFO (" gda session start");
 	qgda_be = (QGdaBackend*)be;
 	be->fullpath = g_strdup (book_path);
+	qgda_be->gda_err = NULL;
 	if(book_path == NULL)
 	{
 		qof_error_set_be (be, qof_error_register
@@ -286,7 +285,6 @@ qgda_session_begin(QofBackend *be, QofSession *session, const
 	}
 	/* check/create the ~/.libgda location. */
 	{
-		gchar * gdahome;
 		struct stat lg;
 		gint ret;
 
@@ -300,26 +298,25 @@ qgda_session_begin(QofBackend *be, QofSession *session, const
 			LEAVE (" unable to use stat on home_dir.");
 			return;
 		}
-		gdahome = g_strconcat (g_get_home_dir(),
-			"/", LIBGDA_DIR, NULL);
+		qgda_be->gdahome = g_strconcat (g_get_home_dir(), "/", LIBGDA_DIR, NULL);
 		if (!S_ISDIR (lg.st_mode) || lg.st_size == 0)
-			ret = g_mkdir_with_parents (gdahome, 0700);
+			ret = g_mkdir_with_parents (qgda_be->gdahome, 0700);
 		if (ret)
 		{
 			qof_error_set_be (be, qof_error_register
 				(_("GDA: Unable to create a .libgda directory "
 				"within your home directory."), FALSE));
 			qgda_be->error = TRUE;
-			LEAVE (" unable to create '%s' 0700", gdahome);
+			LEAVE (" unable to create '%s' 0700", qgda_be->gdahome);
 			return;
 		}
-		g_free (gdahome);
 	}
+	if (qgda_be->data_source_name)
 	{
 		/* check data source */
-		GdaDataSourceInfo * source;
-		gboolean created;
-
+		qgda_be->book = qof_session_get_book (session);
+		PINFO ("name=%s", qgda_be->data_source_name);
+		PINFO ("provider=%s", qgda_be->provider_name);
 		created = FALSE;
 		source = gda_config_find_data_source
 			(qgda_be->data_source_name);
@@ -331,9 +328,8 @@ qgda_session_begin(QofBackend *be, QofSession *session, const
 		if (!source && !created)
 		{
 			qof_error_set_be (be, qof_error_register
-				(_("GDA: No data source found at '%s' - "
-				"Try loading data from another file "
-				"and write to gda: again to create the "
+				(_("GDA: No data source found at '%s' - Try loading data "
+				"from another file and write to gda: again to create the "
 				"GDA data source."), TRUE));
 			DEBUG (" no source but set not to create.");
 			qgda_be->error = TRUE;
@@ -344,7 +340,7 @@ qgda_session_begin(QofBackend *be, QofSession *session, const
 	/* use the username and password that created the source */
 	qgda_be->connection = gda_client_open_connection
 		(qgda_be->client_pool, qgda_be->data_source_name,
-		NULL, NULL, GDA_CONNECTION_OPTIONS_DONT_SHARE, &qgda_err);
+		NULL, NULL, GDA_CONNECTION_OPTIONS_DONT_SHARE, &qgda_be->gda_err);
 	if (qgda_be->connection)
 	{
 		PINFO (" appear to be connected.");
@@ -357,11 +353,19 @@ qgda_session_begin(QofBackend *be, QofSession *session, const
 
 		msg = g_strdup_printf (
 			_("GDA encountered an error '%s' using data source '%s'."),
-				qgda_err->message, qgda_be->data_source_name);
+				qgda_be->gda_err->message, qgda_be->data_source_name);
 		qof_error_set_be (be, qof_error_register (msg, FALSE));
 		PERR (" failed to connect to GDA: '%s'", msg);
 		qgda_be->error = TRUE;
+		g_message (msg);
 		g_free (msg);
+		g_error_free (qgda_be->gda_err);
+#ifdef ONLY_DEBUG
+		/// \bug we probably don't want to remove once out of debug. :-)
+		PERR ("connect request failed, removing %s", qgda_be->data_source_name);
+		g_message ("connect request failed, removing %s", qgda_be->data_source_name);
+		gda_config_remove_data_source (qgda_be->data_source_name);
+#endif
 	}
 }
 
@@ -405,17 +409,17 @@ static void
 qgda_class_foreach (QofObject * obj, gpointer data)
 {
 	QGdaBackend *qgda_be;
-	GError * qgda_err;
 
-	qgda_err = NULL;
 	qgda_be = (QGdaBackend*)data;
-	qgda_be->sql_str = g_strdup_printf(
-		"SELECT * FROM %s;", obj->e_type);
+	qgda_be->gda_err = NULL;
+	qgda_be->sql_str = g_strdup_printf("SELECT * FROM %s;", obj->e_type);
 	PINFO (" sql=%s", qgda_be->sql_str);
 	qgda_be->command = gda_command_new (qgda_be->sql_str,
 		GDA_COMMAND_TYPE_SQL, GDA_COMMAND_OPTION_STOP_ON_ERRORS);
 	qgda_be->entities = gda_connection_execute_command (qgda_be->connection,
-		qgda_be->command, NULL, &qgda_err);
+		qgda_be->command, NULL, &qgda_be->gda_err);
+	if (qgda_be->gda_err)
+		g_error_free (qgda_be->gda_err);
 	g_list_foreach (qgda_be->entities, load_entities, qgda_be);
 	gda_command_free (qgda_be->command);
 }
@@ -433,10 +437,50 @@ qgda_db_load (QofBackend *be, QofBook *book)
 	qof_object_foreach_type(qgda_class_foreach, qgda_be);
 }
 
+static void
+qgda_check_entity (QofEntity * ent, gpointer data)
+{
+	QofInstance *inst;
+	QGdaBackend * qgda_be;
+	gchar * gstr;
+
+	qgda_be = (QGdaBackend*) data;
+	inst = (QofInstance *) ent;
+	if (!inst->dirty)
+		return;
+	/* check if this entity already exists */
+	gstr = g_strnfill (GUID_ENCODING_LENGTH + 1, ' ');
+	guid_to_string_buff (qof_entity_get_guid (ent), gstr);
+	qgda_be->sql_str = g_strdup_printf 
+		("SELECT * FROM %s where guid = \"%s\";", ent->e_type, gstr);
+	qgda_be->dirty_list = NULL;
+	/* assume entity does not yet exist in backend,
+	   e.g. being copied from another session. */
+	qgda_be->exists = FALSE;
+}
+
+static void
+qgda_write_foreach (QofObject * obj, gpointer data)
+{
+	QGdaBackend *qgda_be;
+
+	qgda_be = (QGdaBackend*)data;
+	qgda_be->gda_err = NULL;
+	if (!qof_book_not_saved (qgda_be->book))
+		return;
+	qof_object_foreach (obj->e_type, qgda_be->book, qgda_check_entity, &qgda_be);
+}
+
 static void
 qgda_write_db (QofBackend *be, QofBook *book)
 {
+	QGdaBackend *qgda_be;
 
+	g_return_if_fail (be);
+	qgda_be = (QGdaBackend *) be;
+	qgda_be->book = book;
+	/* update each record with current state */
+	qof_object_foreach_type (qgda_write_foreach, qgda_be);
 }
 
 static void
@@ -445,9 +489,14 @@ qgda_session_end (QofBackend *be)
 	QGdaBackend *qgda_be;
 
 	qgda_be = (QGdaBackend*)be;
-	if (qgda_be->dm)
-		g_object_unref(G_OBJECT(qgda_be->dm));
-	gda_client_close_all_connections (qgda_be->client_pool);
+	if (qgda_be)
+	{
+		/* only remove data_source whilst debugging! */
+		PINFO ("removing %s", qgda_be->data_source_name);
+		gda_config_remove_data_source (qgda_be->data_source_name);
+		gda_client_close_all_connections (qgda_be->client_pool);
+		g_object_unref(G_OBJECT(qgda_be->client_pool));
+	}
 }
 
 static void
@@ -456,8 +505,6 @@ qgda_destroy_backend (QofBackend *be)
 	QGdaBackend *qgda_be;
 
 	qgda_be = (QGdaBackend*)be;
-	if (qgda_be)
-		g_object_unref(G_OBJECT(qgda_be->client_pool));
 	qof_event_unregister_handler (qgda_be->create_handler);
 	qof_event_unregister_handler (qgda_be->delete_handler);
 	g_free (be);
@@ -511,9 +558,7 @@ get_config (QofBackend * be)
 	QGdaBackend *qgda_be;
 
 	if (!be)
-	{
 		return NULL;
-	}
 	ENTER (" ");
 	qgda_be = (QGdaBackend *) be;
 	g_return_val_if_fail (qgda_be, NULL);
@@ -579,6 +624,14 @@ qgda_backend_new (void)
 	gda_init (PACKAGE, "0.1", 0, NULL);
 	qgda_be->client_pool = gda_client_new ();
 	qgda_be->dbversion = QOF_OBJECT_VERSION;
+	qgda_be->err_delete =
+		qof_error_register (_("Unable to delete record."), FALSE);
+	qgda_be->err_create =
+		qof_error_register (_("Unable to create record."), FALSE);
+	qgda_be->err_insert =
+		qof_error_register (_("Unable to insert a new record."), FALSE);
+	qgda_be->err_update =
+		qof_error_register (_("Unable to update existing record."), FALSE);
 	be->session_begin = qgda_session_begin;
 
 	be->session_end = qgda_session_end;
@@ -604,12 +657,12 @@ qgda_backend_new (void)
 	be->get_config = get_config;
 	LEAVE (" ");
 
-/* DEBUG */
+#ifdef ONLY_DEBUG
 	qgda_be->data_source_name = "QOF_DEBUG";
-	qgda_be->database_name = "URI=/home/neil/test.gda";
-	qgda_be->provider_name = "XML";
+	qgda_be->database_name = "DB_DIR=/home/neil/";
+	qgda_be->provider_name = "SQLite";
 	qgda_be->source_description = "QOF GDA debug data";
-/* end debug */
+#endif
 	return be;
 }
 
