@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,17 +54,65 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse sqlparse
-#define yylex   sqllex
-#define yyerror sqlerror
-#define yylval  sqllval
-#define yychar  sqlchar
-#define yydebug sqldebug
-#define yynerrs sqlnerrs
+#define yyparse         sqlparse
+#define yylex           sqllex
+#define yyerror         sqlerror
+#define yylval          sqllval
+#define yychar          sqlchar
+#define yydebug         sqldebug
+#define yynerrs         sqlnerrs
+
+
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 1 "parser.y"
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <glib.h>
+#include <string.h>
+
+#include "sql_parser.h"
+#include "sql_tree.h"
+#include "mem.h"
+
+int sqlerror (char *);
+int sqllex ();
+
+extern sql_statement *sql_result;
+
+
+/* Line 189 of yacc.c  */
+#line 98 "parser.c"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
 
 
 /* Tokens.  */
@@ -191,46 +238,13 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "parser.y"
-
-#include <stdlib.h>
-#include <stdio.h>
-#include <glib.h>
-#include <string.h>
-
-#include "sql_parser.h"
-#include "sql_tree.h"
-#include "mem.h"
-
-int sqlerror (char *);
-int sqllex ();
-
-extern sql_statement *sql_result;
-
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 17 "parser.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 17 "parser.y"
+
 void            *v;
 char            *str;
 int              i;
@@ -242,22 +256,23 @@ sql_condition   *c;
 sql_where       *w;
 param_spec      *ps;
 sql_order_field *of;
-}
-/* Line 187 of yacc.c.  */
-#line 248 "parser.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 264 "parser.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 261 "parser.c"
+/* Line 264 of yacc.c  */
+#line 276 "parser.c"
 
 #ifdef short
 # undef short
@@ -332,14 +347,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -420,9 +435,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -456,12 +471,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -992,17 +1007,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -1036,11 +1054,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1320,10 +1338,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1339,11 +1355,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1351,9 +1366,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1377,14 +1392,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1392,51 +1432,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1466,7 +1483,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1474,7 +1490,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1497,9 +1512,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1510,7 +1524,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1520,6 +1533,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1528,16 +1544,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1569,20 +1585,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1622,479 +1634,668 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 63 "parser.y"
     {sql_result = sql_statement_build (SQL_select, (yyvsp[(1) - (1)].v));}
     break;
 
   case 3:
+
+/* Line 1455 of yacc.c  */
 #line 64 "parser.y"
     {sql_result = sql_statement_build (SQL_insert, (yyvsp[(1) - (1)].v));}
     break;
 
   case 4:
+
+/* Line 1455 of yacc.c  */
 #line 65 "parser.y"
     {sql_result = sql_statement_build (SQL_update, (yyvsp[(1) - (1)].v));}
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 66 "parser.y"
     {sql_result = sql_statement_build (SQL_delete, (yyvsp[(1) - (1)].v));}
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 70 "parser.y"
     {(yyval.v) = sql_select_statement_build ((yyvsp[(2) - (8)].i), (yyvsp[(3) - (8)].list), (yyvsp[(5) - (8)].list), (yyvsp[(6) - (8)].w), (yyvsp[(7) - (8)].list), (yyvsp[(8) - (8)].list));}
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 72 "parser.y"
     {(yyval.v) = sql_select_statement_build ((yyvsp[(2) - (6)].i), (yyvsp[(3) - (6)].list), NULL, (yyvsp[(4) - (6)].w), (yyvsp[(5) - (6)].list), (yyvsp[(6) - (6)].list));}
     break;
 
   case 8:
+
+/* Line 1455 of yacc.c  */
 #line 76 "parser.y"
     {(yyval.v) = sql_insert_statement_build ((yyvsp[(3) - (8)].t), (yyvsp[(4) - (8)].list), (yyvsp[(7) - (8)].list));}
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 80 "parser.y"
     {(yyval.v) = sql_update_statement_build ((yyvsp[(2) - (5)].t), (yyvsp[(4) - (5)].list), (yyvsp[(5) - (5)].w));}
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 84 "parser.y"
     {(yyval.v) = sql_delete_statement_build ((yyvsp[(3) - (4)].t), (yyvsp[(4) - (4)].w));}
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 87 "parser.y"
     {(yyval.list) = g_list_append (NULL, (yyvsp[(1) - (1)].c));}
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 88 "parser.y"
     {(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].c));}
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 91 "parser.y"
     {(yyval.list) = (yyvsp[(2) - (3)].list);}
     break;
 
   case 14:
+
+/* Line 1455 of yacc.c  */
 #line 92 "parser.y"
     {(yyval.list) = NULL;}
     break;
 
   case 15:
+
+/* Line 1455 of yacc.c  */
 #line 95 "parser.y"
     {(yyval.i) = 1;}
     break;
 
   case 16:
+
+/* Line 1455 of yacc.c  */
 #line 96 "parser.y"
     {(yyval.i) = 0;}
     break;
 
   case 17:
+
+/* Line 1455 of yacc.c  */
 #line 99 "parser.y"
     {(yyval.w) = (yyvsp[(2) - (2)].w);}
     break;
 
   case 18:
+
+/* Line 1455 of yacc.c  */
 #line 100 "parser.y"
     {(yyval.w) = NULL;}
     break;
 
   case 19:
+
+/* Line 1455 of yacc.c  */
 #line 103 "parser.y"
     {(yyval.list) = (yyvsp[(3) - (3)].list);}
     break;
 
   case 20:
+
+/* Line 1455 of yacc.c  */
 #line 104 "parser.y"
     {(yyval.list) = NULL;}
     break;
 
   case 21:
+
+/* Line 1455 of yacc.c  */
 #line 107 "parser.y"
     {(yyval.list) = g_list_append (NULL, (yyvsp[(1) - (1)].of));}
     break;
 
   case 22:
+
+/* Line 1455 of yacc.c  */
 #line 108 "parser.y"
     {(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].of));}
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 111 "parser.y"
     {(yyval.of) = sql_order_field_build ((yyvsp[(1) - (1)].list), SQL_asc);}
     break;
 
   case 24:
+
+/* Line 1455 of yacc.c  */
 #line 112 "parser.y"
     {(yyval.of) = sql_order_field_build ((yyvsp[(1) - (2)].list), SQL_asc);}
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 113 "parser.y"
     {(yyval.of) = sql_order_field_build ((yyvsp[(1) - (2)].list), SQL_desc);}
     break;
 
   case 26:
+
+/* Line 1455 of yacc.c  */
 #line 116 "parser.y"
     {(yyval.list) = (yyvsp[(3) - (3)].list);}
     break;
 
   case 27:
+
+/* Line 1455 of yacc.c  */
 #line 117 "parser.y"
     {(yyval.list) = NULL;}
     break;
 
   case 28:
+
+/* Line 1455 of yacc.c  */
 #line 120 "parser.y"
     {(yyval.list) = g_list_append (NULL, (yyvsp[(1) - (1)].f));}
     break;
 
   case 29:
+
+/* Line 1455 of yacc.c  */
 #line 121 "parser.y"
     {(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].f));}
     break;
 
   case 30:
+
+/* Line 1455 of yacc.c  */
 #line 124 "parser.y"
     {(yyval.i) = SQL_left_join;}
     break;
 
   case 31:
+
+/* Line 1455 of yacc.c  */
 #line 125 "parser.y"
     {(yyval.i) = SQL_left_join;}
     break;
 
   case 32:
+
+/* Line 1455 of yacc.c  */
 #line 126 "parser.y"
     {(yyval.i) = SQL_right_join;}
     break;
 
   case 33:
+
+/* Line 1455 of yacc.c  */
 #line 127 "parser.y"
     {(yyval.i) = SQL_right_join;}
     break;
 
   case 34:
+
+/* Line 1455 of yacc.c  */
 #line 128 "parser.y"
     {(yyval.i) = SQL_full_join;}
     break;
 
   case 35:
+
+/* Line 1455 of yacc.c  */
 #line 129 "parser.y"
     {(yyval.i) = SQL_full_join;}
     break;
 
   case 36:
+
+/* Line 1455 of yacc.c  */
 #line 130 "parser.y"
     {(yyval.i) = SQL_inner_join;}
     break;
 
   case 37:
+
+/* Line 1455 of yacc.c  */
 #line 131 "parser.y"
     {(yyval.i) = SQL_inner_join;}
     break;
 
   case 38:
+
+/* Line 1455 of yacc.c  */
 #line 134 "parser.y"
     {(yyval.list) = g_list_append (NULL, (yyvsp[(1) - (1)].t));}
     break;
 
   case 39:
+
+/* Line 1455 of yacc.c  */
 #line 135 "parser.y"
     {(yyval.list) = g_list_append ((yyvsp[(1) - (3)].list), (yyvsp[(3) - (3)].t));}
     break;
 
   case 40:
+
+/* Line 1455 of yacc.c  */
 #line 136 "parser.y"
     {(yyval.list) = g_list_append ((yyvsp[(1) - (3)].list), sql_table_set_join ((yyvsp[(3) - (3)].t), (yyvsp[(2) - (3)].i), NULL));}
     break;
 
   case 41:
+
+/* Line 1455 of yacc.c  */
 #line 137 "parser.y"
     {(yyval.list) = g_list_append ((yyvsp[(1) - (5)].list), sql_table_set_join ((yyvsp[(3) - (5)].t), (yyvsp[(2) - (5)].i), (yyvsp[(5) - (5)].w)));}
     break;
 
   case 42:
+
+/* Line 1455 of yacc.c  */
 #line 140 "parser.y"
     {(yyval.t) = sql_table_build ((yyvsp[(1) - (1)].str)); memsql_free ((yyvsp[(1) - (1)].str));}
     break;
 
   case 43:
+
+/* Line 1455 of yacc.c  */
 #line 141 "parser.y"
     {(yyval.t) = sql_table_set_as ((yyvsp[(1) - (3)].t), (yyvsp[(3) - (3)].str));}
     break;
 
   case 44:
+
+/* Line 1455 of yacc.c  */
 #line 142 "parser.y"
     {(yyval.t) = sql_table_set_as ((yyvsp[(1) - (2)].t), (yyvsp[(2) - (2)].str));}
     break;
 
   case 45:
+
+/* Line 1455 of yacc.c  */
 #line 143 "parser.y"
     {(yyval.t) = sql_table_build_select ((yyvsp[(1) - (1)].v));}
     break;
 
   case 46:
+
+/* Line 1455 of yacc.c  */
 #line 144 "parser.y"
     {(yyval.t) = (yyvsp[(2) - (3)].t);}
     break;
 
   case 47:
+
+/* Line 1455 of yacc.c  */
 #line 147 "parser.y"
     {(yyval.f) = sql_field_build ((yyvsp[(1) - (1)].fi));}
     break;
 
   case 48:
+
+/* Line 1455 of yacc.c  */
 #line 148 "parser.y"
     {(yyval.f) = sql_field_set_as (sql_field_build ((yyvsp[(1) - (3)].fi)), (yyvsp[(3) - (3)].str));}
     break;
 
   case 49:
+
+/* Line 1455 of yacc.c  */
 #line 149 "parser.y"
     {(yyval.f) = sql_field_set_as (sql_field_build ((yyvsp[(1) - (3)].fi)), (yyvsp[(3) - (3)].str));}
     break;
 
   case 50:
+
+/* Line 1455 of yacc.c  */
 #line 150 "parser.y"
     {(yyval.f) = sql_field_set_param_spec (sql_field_build ((yyvsp[(1) - (2)].fi)), (yyvsp[(2) - (2)].list));}
     break;
 
   case 51:
+
+/* Line 1455 of yacc.c  */
 #line 151 "parser.y"
     {(yyval.f) = sql_field_set_as (sql_field_set_param_spec (sql_field_build ((yyvsp[(1) - (4)].fi)), (yyvsp[(2) - (4)].list)), (yyvsp[(4) - (4)].str));}
     break;
 
   case 52:
+
+/* Line 1455 of yacc.c  */
 #line 154 "parser.y"
     {(yyval.list) = g_list_append (NULL, memsql_strdup ((yyvsp[(1) - (1)].str))); memsql_free ((yyvsp[(1) - (1)].str));}
     break;
 
   case 53:
+
+/* Line 1455 of yacc.c  */
 #line 155 "parser.y"
     {(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), memsql_strdup ((yyvsp[(1) - (3)].str))); memsql_free ((yyvsp[(1) - (3)].str));}
     break;
 
   case 54:
+
+/* Line 1455 of yacc.c  */
 #line 156 "parser.y"
     {(yyval.list) = g_list_append (NULL, memsql_strdup ((yyvsp[(1) - (3)].str))); memsql_free ((yyvsp[(1) - (3)].str));
 					 (yyval.list) = g_list_append ((yyval.list), memsql_strdup ("*"));}
     break;
 
   case 55:
+
+/* Line 1455 of yacc.c  */
 #line 160 "parser.y"
     {(yyval.list) = (yyvsp[(1) - (1)].list);}
     break;
 
   case 56:
+
+/* Line 1455 of yacc.c  */
 #line 161 "parser.y"
     {(yyval.list) = g_list_append (NULL, memsql_strdup ("*"));}
     break;
 
   case 57:
+
+/* Line 1455 of yacc.c  */
 #line 162 "parser.y"
     {(yyval.list) = g_list_append (NULL, memsql_strdup ("null"));}
     break;
 
   case 58:
+
+/* Line 1455 of yacc.c  */
 #line 163 "parser.y"
     {(yyval.list) = g_list_append (NULL, (yyvsp[(1) - (1)].str));}
     break;
 
   case 59:
+
+/* Line 1455 of yacc.c  */
 #line 167 "parser.y"
     {(yyval.i) = SQL_minus;}
     break;
 
   case 60:
+
+/* Line 1455 of yacc.c  */
 #line 168 "parser.y"
     {(yyval.i) = SQL_plus;}
     break;
 
   case 61:
+
+/* Line 1455 of yacc.c  */
 #line 169 "parser.y"
     {(yyval.i) = SQL_times;}
     break;
 
   case 62:
+
+/* Line 1455 of yacc.c  */
 #line 170 "parser.y"
     {(yyval.i) = SQL_div;}
     break;
 
   case 63:
+
+/* Line 1455 of yacc.c  */
 #line 173 "parser.y"
     {(yyval.fi) = sql_field_item_build ((yyvsp[(1) - (1)].list));}
     break;
 
   case 64:
+
+/* Line 1455 of yacc.c  */
 #line 174 "parser.y"
     {(yyval.fi) = sql_field_item_build_equation ((yyvsp[(1) - (3)].fi), (yyvsp[(3) - (3)].fi), (yyvsp[(2) - (3)].i));}
     break;
 
   case 65:
+
+/* Line 1455 of yacc.c  */
 #line 175 "parser.y"
     {(yyval.fi) = sql_field_item_build_select ((yyvsp[(1) - (1)].v));}
     break;
 
   case 66:
+
+/* Line 1455 of yacc.c  */
 #line 176 "parser.y"
     {(yyval.fi) = (yyvsp[(2) - (3)].fi);}
     break;
 
   case 67:
+
+/* Line 1455 of yacc.c  */
 #line 177 "parser.y"
     {(yyval.fi) = sql_field_build_function((yyvsp[(1) - (4)].str), (yyvsp[(3) - (4)].list)); }
     break;
 
   case 68:
+
+/* Line 1455 of yacc.c  */
 #line 178 "parser.y"
     {(yyval.fi) = sql_field_build_function((yyvsp[(1) - (3)].str), NULL); }
     break;
 
   case 69:
+
+/* Line 1455 of yacc.c  */
 #line 181 "parser.y"
     {(yyval.w) = sql_where_build_single ((yyvsp[(1) - (1)].c));}
     break;
 
   case 70:
+
+/* Line 1455 of yacc.c  */
 #line 182 "parser.y"
     {(yyval.w) = sql_where_build_negated ((yyvsp[(2) - (2)].w));}
     break;
 
   case 71:
+
+/* Line 1455 of yacc.c  */
 #line 183 "parser.y"
     {(yyval.w) = sql_where_build_pair ((yyvsp[(1) - (3)].w), (yyvsp[(3) - (3)].w), SQL_or);}
     break;
 
   case 72:
+
+/* Line 1455 of yacc.c  */
 #line 184 "parser.y"
     {(yyval.w) = sql_where_build_pair ((yyvsp[(1) - (3)].w), (yyvsp[(3) - (3)].w), SQL_and);}
     break;
 
   case 73:
+
+/* Line 1455 of yacc.c  */
 #line 185 "parser.y"
     {(yyval.w) = (yyvsp[(2) - (3)].w);}
     break;
 
   case 74:
+
+/* Line 1455 of yacc.c  */
 #line 188 "parser.y"
     {(yyval.c) = sql_build_condition ((yyvsp[(1) - (3)].f), (yyvsp[(3) - (3)].f), SQL_eq);}
     break;
 
   case 75:
+
+/* Line 1455 of yacc.c  */
 #line 191 "parser.y"
     {(yyval.i) = SQL_eq;}
     break;
 
   case 76:
+
+/* Line 1455 of yacc.c  */
 #line 192 "parser.y"
     {(yyval.i) = SQL_is;}
     break;
 
   case 77:
+
+/* Line 1455 of yacc.c  */
 #line 193 "parser.y"
     {(yyval.i) = SQL_isnot;}
     break;
 
   case 78:
+
+/* Line 1455 of yacc.c  */
 #line 194 "parser.y"
     {(yyval.i) = SQL_in;}
     break;
 
   case 79:
+
+/* Line 1455 of yacc.c  */
 #line 195 "parser.y"
     {(yyval.i) = SQL_notin;}
     break;
 
   case 80:
+
+/* Line 1455 of yacc.c  */
 #line 196 "parser.y"
     {(yyval.i) = SQL_like;}
     break;
 
   case 81:
+
+/* Line 1455 of yacc.c  */
 #line 197 "parser.y"
     {(yyval.i) = SQL_gt;}
     break;
 
   case 82:
+
+/* Line 1455 of yacc.c  */
 #line 198 "parser.y"
     {(yyval.i) = SQL_lt;}
     break;
 
   case 83:
+
+/* Line 1455 of yacc.c  */
 #line 199 "parser.y"
     {(yyval.i) = SQL_geq;}
     break;
 
   case 84:
+
+/* Line 1455 of yacc.c  */
 #line 200 "parser.y"
     {(yyval.i) = SQL_leq;}
     break;
 
   case 85:
+
+/* Line 1455 of yacc.c  */
 #line 201 "parser.y"
     {(yyval.i) = SQL_diff;}
     break;
 
   case 86:
+
+/* Line 1455 of yacc.c  */
 #line 204 "parser.y"
     {(yyval.c) = sql_build_condition ((yyvsp[(1) - (3)].f), (yyvsp[(3) - (3)].f), (yyvsp[(2) - (3)].i));}
     break;
 
   case 87:
+
+/* Line 1455 of yacc.c  */
 #line 205 "parser.y"
     {(yyval.c) = sql_build_condition_between ((yyvsp[(1) - (5)].f), (yyvsp[(3) - (5)].f), (yyvsp[(5) - (5)].f));}
     break;
 
   case 88:
+
+/* Line 1455 of yacc.c  */
 #line 208 "parser.y"
     {(yyval.list) = (yyvsp[(2) - (3)].list);}
     break;
 
   case 89:
+
+/* Line 1455 of yacc.c  */
 #line 211 "parser.y"
     {(yyval.list) = g_list_append (NULL, (yyvsp[(1) - (1)].ps));}
     break;
 
   case 90:
+
+/* Line 1455 of yacc.c  */
 #line 212 "parser.y"
     {(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].ps));}
     break;
 
   case 91:
+
+/* Line 1455 of yacc.c  */
 #line 216 "parser.y"
     {(yyval.ps) = param_spec_build (PARAM_name, (yyvsp[(3) - (3)].str));}
     break;
 
   case 92:
+
+/* Line 1455 of yacc.c  */
 #line 217 "parser.y"
     {(yyval.ps) = param_spec_build (PARAM_descr, (yyvsp[(3) - (3)].str));}
     break;
 
   case 93:
+
+/* Line 1455 of yacc.c  */
 #line 218 "parser.y"
     {(yyval.ps) = param_spec_build (PARAM_type, (yyvsp[(3) - (3)].str));}
     break;
 
   case 94:
+
+/* Line 1455 of yacc.c  */
 #line 219 "parser.y"
     {(yyval.ps) = param_spec_build (PARAM_isparam, (yyvsp[(3) - (3)].str));}
     break;
 
   case 95:
+
+/* Line 1455 of yacc.c  */
 #line 220 "parser.y"
     {(yyval.ps) = param_spec_build (PARAM_nullok, (yyvsp[(3) - (3)].str));}
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 2098 "parser.c"
+
+/* Line 1455 of yacc.c  */
+#line 2299 "parser.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2105,7 +2306,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2170,7 +2370,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2187,7 +2387,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2244,9 +2444,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2271,7 +2468,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2282,7 +2479,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2308,6 +2505,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 222 "parser.y"
 
 
