@@ -42,6 +42,8 @@
 	@addtogroup Backend Backends: Permanent storage for QOF entities.
 	@ingroup QOF
     @addtogroup Query Query:      Querying for Objects
+    @ingroup QOF
+    @addtogroup SQL SQL Interface to Query
     @ingroup QOF
 	@addtogroup Error Error: Extensible error handling.
 	@ingroup QOF
@@ -72,7 +74,6 @@
 #include "guid.h"
 #include "kvpframe.h"
 #include "kvputil.h"
-#include "kvputil-p.h"
 #include "qofbackend.h"
 #include "qofid-p.h"
 #include "qofinstance-p.h"
@@ -88,9 +89,8 @@
 #include "qofchoice.h"
 #include "qofbookmerge.h"
 #include "qofreference.h"
-#include "qofla-dir.h"
 #include "qofundo.h"
-#include "deprecated.h"
+//#include "deprecated.h"
 
 /** allow easy logging of QSF debug messages */
 #define QOF_MOD_QSF "qof-backend-qsf"
