@@ -113,12 +113,14 @@
 typedef struct _QofSession QofSession;
 
 QofSession *qof_session_new (void);
+
 void qof_session_destroy (QofSession * session);
 
 /** The qof_session_swap_data () method swaps the book of
  *    the two given sessions. It is useful
  *    for 'Save As' type functionality. */
-void qof_session_swap_data (QofSession * session_1, QofSession * session_2);
+void 
+qof_session_swap_data (QofSession * session_1, QofSession * session_2);
 
 /** The qof_session_begin () method begins a new session.
  *    It takes as an argument the book id. The book id must be a string
@@ -147,7 +149,7 @@ void qof_session_swap_data (QofSession * session_1, QofSession * session_2);
  *    If an error occurs, it will be pushed onto the session error
  *    stack, and that is where it should be examined.
  */
-void qof_session_begin (QofSession * session, const char *book_id,
+void qof_session_begin (QofSession * session, const gchar *book_id,
 						gboolean ignore_lock, gboolean create_if_nonexistent);
 
 /**
@@ -163,31 +165,10 @@ void qof_session_begin (QofSession * session, const char *book_id,
  * wrong to me, and should be restricted to allow only one load per 
  * session.
  */
-typedef void (*QofPercentageFunc) (const gchar *message, double percent);
+typedef void (*QofPercentageFunc) (const gchar *message, gdouble percent);
 void qof_session_load (QofSession * session,
 					   QofPercentageFunc percentage_func);
 
-/** @name Session Errors 
- @{ */
-/** The qof_session_get_error() routine can be used to obtain the reason
- *    for any failure.  Calling this routine returns the current error.
- */
-QofBackendError qof_session_get_error (QofSession * session);
-const gchar *qof_session_get_error_message (QofSession * session);
-
-/**
- * The qof_session_pop_error() routine can be used to obtain the reason
- *    for any failure.  Calling this routine resets the error value.  
- *
- *    This routine allows an implementation of multiple error values, 
- *    e.g. in a stack, where this routine pops the top value. The current 
- *    implementation has a stack that is one-deep.
- *
- *    See qofbackend.h for a listing of returned errors.
- */
-QofBackendError qof_session_pop_error (QofSession * session);
-/** @} */
-
 /** The qof_session_add_book() allows additional books to be added to
  *    a session. 
  * XXX Under construction, clarify the following when done:
@@ -195,9 +176,11 @@ QofBackendError qof_session_pop_error (QofSession * session);
  * XXX Only one open book at a time per session is allowed!?
  * XXX each book gets its own unique backend ???
  */
-void qof_session_add_book (QofSession * session, QofBook * book);
+void 
+qof_session_add_book (QofSession * session, QofBook * book);
 
-QofBook *qof_session_get_book (QofSession * session);
+QofBook *
+qof_session_get_book (QofSession * session);
 
 /**
  *    The qof_session_get_file_path() routine returns the fully-qualified file
@@ -432,5 +415,7 @@ void qof_session_add_close_hook (GFunc fn, gpointer data);
  *  @param session A pointer to the session being closed. */
 void qof_session_call_close_hooks (QofSession * session);
 
-#endif /* QOF_SESSION_H */
 /** @} */
+/** @} */
+
+#endif /* QOF_SESSION_H */
