@@ -92,14 +92,6 @@
 
 /** log module name */
 #define QOF_MOD_TIME "qof-time"
-/** \deprecated use ::QofTime. */
-#ifndef QOF_DISABLE_DEPRECATED
-typedef struct timespec64
-{
-   guint64 tv_sec;
-   glong tv_nsec;
-}Timespec;
-#endif
 
 /** number of nanoseconds per second. 10^9 */
 #define QOF_NSECS 1000000000
